# Generated by Django 3.2.22 on 2023-10-25 08:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0005_auto_20220310_1544'),
    ]

    operations = [
        migrations.AlterField(
            model_name='warning',
            name='status',
            field=models.IntegerField(choices=[(10, 'Message Not sent yet'), (20, 'Message is sending'), (30, 'Messgage Sent')], default=10, editable=False, verbose_name='Notify Status'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='success',
            field=models.BooleanField(editable=False, null=True, verbose_name='Notify Sent Success'),
        ),
    ]
